@@ -9,14 +9,15 @@
 #define POLYGON_H
 
 #include <qtimer.h>
-#include <Q3PointArray>
-#include <Q3MemArray>
-#include <Q3PtrList>
+#include <QVector>
+#include <QList>
 
 #include <kdialog.h>
 #include <kscreensaver.h>
 #include <krandomsequence.h>
 
+class QPolygon;
+
 class kPolygonSaver : public KScreenSaver
 {
 	Q_OBJECT
@@ -39,13 +40,13 @@ protected:
 
 protected:
 	QTimer		timer;
-	unsigned	numLines;
+	int			numLines;
 	int			numVertices;
 	int			speed;
 	QColor		colors[64];
     int         currentColor;
-	Q3PtrList<Q3PointArray> polygons;
-	Q3MemArray<QPoint> directions;
+	QList<QPolygon> polygons;
+	QVector<QPoint> directions;
 	KRandomSequence rnd;
 };
 
